/**
 * The content class is a class that deals with content when it is discovered.
 */

#ifndef CONTENT_H
#define CONTENT_H
#include "threaded_hash.h"

/* Structure for keeping track of file segments */
class seg {
public:;
    uint64_t fs_offset;		    // byte offset from start of file system
    uint64_t img_offset;		    // offset from beginning of image
    uint64_t file_offset;		    // logical number of bytes from beginning of file
    uint64_t len;		    // number of bytes
    TSK_FS_BLOCK_FLAG_ENUM flags;   // 
};

typedef vector<class seg> seglist;	// vector of blocks
class content {
private:
    string   evidence_filename;         // filename of what's currently being saved (from evidence file system)
    void     open_tempfile();
    void     open_savefile();
public:
    bool     do_plugin;
    void     set_filename(const string &filename);
    bool     need_file_walk();	        // true if we need the full content or disk sectors
    bool     name_filtered();
    string   evidence_dirname;		// where it is being put


    FILE    *savefile;		        // saving the copy for posterity
    string   save_path;	                // full path of where it is being saved

    FILE    *tempfile;			// copy for plugin and "file" command
    string  tempdir;			// directory where temporary files are put
    string  tempfile_path;		// where the tempfile was put

    threaded_hash h_md5;
    threaded_hash h_sha1;
    seglist segs;			// the segments that make up the file

    content():savefile(0),
		   tempfile(0),
		   tempdir("/tmp"),
		   h_md5(EVP_md5,opt_multithreaded),
		   h_sha1(EVP_sha1,opt_multithreaded) {
    }
    bool   has_filename() { return evidence_filename.size()>0;}
    string filename()     { return evidence_dirname + evidence_filename; }
    string filemagic();			// returns output of the 'file' command or libmagic
    void   add_seg(int64_t img_offset,int64_t fs_offset,int64_t file_offset,int64_t len,
		   TSK_FS_BLOCK_FLAG_ENUM flags);

    void add_bytes(const char *buf,size_t size);
    void final();
    void write_record();		// writes the ARFF record for this content
    ~content(){
	if(tempfile_path.size()>0) unlink(tempfile_path.c_str());
    }
};

#endif
